@@ -17,7 +17,7 @@ use Net::Statsd::Lite::Types -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.3.0';
+our $VERSION = 'v0.3.1';
 
 
 has host => (
@@ -219,13 +219,13 @@ Net::Statsd::Lite - A lightweight StatsD client that supports multimetric packet
 
 =head1 VERSION
 
-version v0.3.0
+version v0.3.1
 
 =head1 SYNOPSIS
 
-    use Net::Statsd::Tiny;
+    use Net::Statsd::Lite;
 
-    my $stats = Net::Statsd::Tiny->new(
+    my $stats = Net::Statsd::Lite->new(
       prefix          => 'myapp.',
       autoflush       => 0,
       max_buffer_size => 8192,
